colour.models.dataset.color_match_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.color_match_rgb Module

## ColorMatch RGB Colourspace

Defines the ColorMatch RGB colourspace:

- `COLOR_MATCH_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.brucelindbloom.com/WorkingSpaceInfo.html (Last accessed 11 April 2014)

`colour.models.dataset.color_match_rgb.` `COLOR_MATCH_RGB_PRIMARIES` = array([[ 0.63 , 0.34 ], [ 0.295, 0.605], [ 0.15 , 0.075]])

  ColorMatch RGB colourspace primaries.

  COLOR_MATCH_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.color_match_rgb.` `COLOR_MATCH_RGB_WHITEPOINT` = (0.34567, 0.3585)

  ColorMatch RGB colourspace whitepoint.

  COLOR_MATCH_RGB_WHITEPOINT : tuple

`colour.models.dataset.color_match_rgb.` `COLOR_MATCH_RGB_TO_XYZ_MATRIX` = array([[ 0.50933743, 0.32090983, 0.13396473], [ 0.27488052, 0.65813712, 0.06698237], [ 0.02425416, 0.10878299, 0.69215113]])

  ColorMatch RGB colourspace to CIE XYZ colourspace matrix.

  COLOR_MATCH_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.color_match_rgb.` `XYZ_TO_COLOR_MATCH_RGB_MATRIX` = array([[ 2.64232075, -1.22344247, -0.39301926], [-1.11196676, 2.05900066, 0.01596125], [ 0.08217251, -0.28073448, 1.45603468]])

  CIE XYZ colourspace to ColorMatch RGB colourspace matrix.

  XYZ_TO_COLOR_MATCH_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.color_match_rgb.` `COLOR_MATCH_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to ColorMatch RGB colourspace.

  COLOR_MATCH_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.color_match_rgb.` `COLOR_MATCH_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from ColorMatch RGB colourspace to linear.

  COLOR_MATCH_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.color_match_rgb.` `COLOR_MATCH_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d890>

  ColorMatch RGB colourspace.

  COLOR_MATCH_RGB_COLOURSPACE : RGB_Colourspace